QuotationMark enum
Enumeration allowing the user to choose between quotation mark delimiters.
Values
- single → const QuotationMark
-
Instance of an enumeration. Represent a single quotation mark.
const QuotationMark('\'') - double → const QuotationMark
-
Instance of an enumeration. Represents a double quotation mark.
const QuotationMark('"')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
Returns the String symbol representing the quotation mark.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QuotationMark> - A constant List of the values in this enum, in order of their declaration.