Quote extension
Extension on StringBuffer providing methods for converting objects to String literals enclosed by quotation marks.
- on
Methods
-
writeAllQ(
Iterable objects, {QuotationMark delimiter = QuotationMark.single, String separator = ', '}) → void -
Available on StringBuffer, provided by the Quote extension
Writesobjectsin sequence to the buffer. -
writelnAll(
Iterable objects, [String separator = '']) → void -
Available on StringBuffer, provided by the Quote extension
Writesobjectsin sequence to the buffer. -
writelnAllQ(
Iterable objects, {String separator1 = '', String separator2 = '', QuotationMark delimiter = QuotationMark.single}) → void -
Available on StringBuffer, provided by the Quote extension
Writesobjectsin sequence to the buffer. -
writelnQ(
Object object, {QuotationMark delimiter = QuotationMark.single}) → void -
Available on StringBuffer, provided by the Quote extension
Enclosesobjwithdelimiter, adds a newline symbol and adds the resultingStringto the buffer. -
writeQ(
Object obj, {QuotationMark delimiter = QuotationMark.single}) → void -
Available on StringBuffer, provided by the Quote extension
Enclosesobjwithdelimiterand writes the resultingStringto the buffer.